Export Package VRC : bcB61Ma6ca02
Update compared VRC:   B61Xa ca02
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : No
Library sources    : No
Creation Date      : 040810 13:43:04
Total file size    : 3330107
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
S = Subscription Templates
b = Functions
A = Additional Files
h = Help Text Codes
Q = SQL Queries
P = Customization Projects
----------------------
dbcttd.0401                                           B61Ma3ca02 (not expired)
dbcttd.0401.1                                         B61Ma3ca02 (not expired)
dbcttf.stat                                           B61Ma2ca02 (not expired)
tbcttf001                                             B61Ma1ca02 (not expired)
tbcttf002                                             B61Ma1ca02 (not expired)
tbcttf005                                             B61Ma1ca02 (not expired)
tbcttf106                                             B61Ma2ca02 (not expired)
tbctti001                                             B61Ma2ca02 (not expired)
sbccor0201m000                                        B61Ma ca02 (not expired)
sbccor0202m000                                        B61Ma ca02 (not expired)
sbccor0205m000                                        B61Ma ca02 (not expired)
sbccor0208m000                                        B61Ma1ca02 (not expired)
sbccor0213m000                                        B61Ma ca02 (not expired)
sbccor0215m000                                        B61Ma1ca02 (not expired)
sbccor0217m000                                        B61Ma ca02 (not expired)
sbccor0218m000                                        B61Ma ca02 (not expired)
sbccor0219m000                                        B61Ma1ca02 (not expired)
sbccor0221m000                                        B61Ma1ca02 (not expired)
sbccor0222m000                                        B61Ma1ca02 (not expired)
sbccor0224m000                                        B61Ma1ca02 (not expired)
sbccor0225m000                                        B61Ma3ca02 (not expired)
sbccor0226m000                                        B61Ma3ca02 (not expired)
sbccor0227m000                                        B61Ma3ca02 (not expired)
sbccor0228m000                                        B61Ma3ca02 (not expired)
sbccor0229m000                                        B61Ma3ca02 (not expired)
sbccor0230m000                                        B61Ma3ca02 (not expired)
sbccor0231m000                                        B61Ma3ca02 (not expired)
sbccor0232m000                                        B61Ma3ca02 (not expired)
sbccor0233m000                                        B61Ma3ca02 (not expired)
sbccor0234m000                                        B61Ma3ca02 (not expired)
sbccor0235m000                                        B61Ma3ca02 (not expired)
sbccor0236m000                                        B61Ma3ca02 (not expired)
sbccor0237m000                                        B61Ma3ca02 (not expired)
sbccor0238m000                                        B61Ma3ca02 (not expired)
sbccor0239m000                                        B61Ma3ca02 (not expired)
sbccor0240m000                                        B61Ma3ca02 (not expired)
sbccor0241m000                                        B61Ma3ca02 (not expired)
sbccor0242m000                                        B61Ma3ca02 (not expired)
sbccor0297m000                                        B61Ma3ca02 (not expired)
sbccor0298m000                                        B61Ma3ca02 (not expired)
sbcttc0201m000                                        B61Ma3ca02 (not expired)
sbcttd0401m000                                        B61Ma3ca02 (not expired)
sbcttf0105m000                                        B61Ma2ca02 (not expired)
sbcttf0201m000                                        B61Ma2ca02 (not expired)
sbcttf0220m000                                        B61Ma3ca02 (not expired)
sbcttf0238m000                                        B61Ma3ca02 (not expired)
sbcttf1206m000                                        B61Ma2ca02 (not expired)
sbcttf1206m100                                        B61Ma2ca02 (not expired)
sbcttf2250m000                                        B61Ma5ca02 (expired)
sbcttf4529m000                                        B61Ma3ca02 (not expired)
sbctti0202m000                                        B61Ma1ca02 (not expired)
sbctti0203m000                                        B61Ma1ca02 (not expired)
sbctti7200m000                                        B61Ma2ca02 (not expired)
sbcttt9200m000                                        B61Ma3ca02 (not expired)
pbccor0001                                            B61Ma2ca02 (without source) (not expired)
pbccor0200                                            B61Ma ca02 (without source) (not expired)
pbccor0201                                            B61Ma ca02 (without source) (not expired)
pbccor0202                                            B61Ma ca02 (without source) (not expired)
pbccor0203                                            B61Ma2ca02 (without source) (not expired)
pbccor0204                                            B61Ma ca02 (without source) (not expired)
pbccor0205                                            B61Ma ca02 (without source) (not expired)
pbccor0206                                            B61Ma1ca02 (without source) (not expired)
pbccor0207                                            B61Ma ca02 (without source) (not expired)
pbccor0208                                            B61Ma1ca02 (without source) (not expired)
pbccor0210                                            B61Ma ca02 (without source) (not expired)
pbccor0211                                            B61Ma ca02 (without source) (not expired)
pbccor0212                                            B61Ma ca02 (without source) (not expired)
pbccor0213                                            B61Ma ca02 (without source) (not expired)
pbccor0215                                            B61Ma5ca02 (without source) (not expired)
pbccor0216                                            B61Ma ca02 (without source) (not expired)
pbccor0217                                            B61Ma ca02 (without source) (not expired)
pbccor0218                                            B61Ma ca02 (without source) (not expired)
pbccor0219                                            B61Ma1ca02 (without source) (not expired)
pbccor0220                                            B61Ma1ca02 (without source) (not expired)
pbccor0221                                            B61Ma1ca02 (without source) (not expired)
pbccor0222                                            B61Ma1ca02 (without source) (not expired)
pbccor0223                                            B61Ma1ca02 (without source) (expired)
pbccor0224                                            B61Ma1ca02 (without source) (not expired)
pbccor0225                                            B61Ma3ca02 (without source) (not expired)
pbccor0226                                            B61Ma3ca02 (without source) (not expired)
pbccor0227                                            B61Ma3ca02 (without source) (not expired)
pbccor0228                                            B61Ma3ca02 (without source) (not expired)
pbccor0229                                            B61Ma3ca02 (without source) (not expired)
pbccor0230                                            B61Ma3ca02 (without source) (not expired)
pbccor0231                                            B61Ma3ca02 (without source) (not expired)
pbccor0232                                            B61Ma3ca02 (without source) (not expired)
pbccor0233                                            B61Ma3ca02 (without source) (not expired)
pbccor0235                                            B61Ma3ca02 (without source) (not expired)
pbccor0236                                            B61Ma3ca02 (without source) (not expired)
pbccor0237                                            B61Ma3ca02 (without source) (not expired)
pbccor0238                                            B61Ma3ca02 (without source) (not expired)
pbccor0239                                            B61Ma3ca02 (without source) (not expired)
pbccor0240                                            B61Ma3ca02 (without source) (not expired)
pbccor0241                                            B61Ma3ca02 (without source) (not expired)
pbccor0242                                            B61Ma3ca02 (without source) (not expired)
pbccor0297                                            B61Ma3ca02 (without source) (not expired)
pbccor0299                                            B61Ma3ca02 (without source) (not expired)
pbccor9000                                            B61Ma2ca02 (without source) (not expired)
pbccortabledesc                                       B61Ma5ca02 (without source) (not expired)
pbccortestgz                                          B61Ma ca02 (without source) (expired)
pbccorts220                                           B61Ma ca02 (without source) (not expired)
pbcintdlltcfin                                        B61Ma5ca02 (without source) (not expired)
pbcttc0201                                            B61Ma3ca02 (without source) (not expired)
pbcttcdll0001                                         B61Ma3ca02 (without source) (not expired)
pbcttd0401                                            B61Ma3ca02 (without source) (not expired)
pbcttddll0001                                         B61Ma2ca02 (without source) (not expired)
pbcttf0201                                            B61Ma5ca02 (without source) (not expired)
pbcttf0220                                            B61Ma3ca02 (without source) (not expired)
pbcttf0238                                            B61Ma3ca02 (without source) (not expired)
pbcttf1206                                            B61Ma2ca02 (without source) (not expired)
pbcttf1206m100                                        B61Ma2ca02 (without source) (not expired)
pbcttf2250                                            B61Ma5ca02 (without source) (expired)
pbcttf4529                                            B61Ma3ca02 (without source) (not expired)
pbcttfdll0001                                         B61Ma2ca02 (without source) (not expired)
pbcttfdll0002                                         B61Ma2ca02 (without source) (not expired)
pbcttfdll0003                                         B61Ma2ca02 (without source) (not expired)
pbcttfdll0004                                         B61Ma ca02 (without source) (not expired)
pbcttfdll0005                                         B61Ma1ca02 (without source) (not expired)
pbcttfdll0006                                         B61Ma2ca02 (without source) (not expired)
pbcttfdll0008                                         B61Ma5ca02 (without source) (not expired)
pbcttfdll0238                                         B61Ma3ca02 (without source) (not expired)
pbctti0202                                            B61Ma1ca02 (without source) (not expired)
pbctti0203                                            B61Ma1ca02 (without source) (not expired)
pbctti7200                                            B61Ma2ca02 (without source) (not expired)
pbcttidll0001                                         B61Ma5ca02 (without source) (not expired)
pbcttidll00013                                        B61Ma2ca02 (without source) (not expired)
pbcttidll0002                                         B61Ma2ca02 (without source) (not expired)
pbcttidll0003                                         B61Ma5ca02 (without source) (not expired)
pbcttidll0004                                         B61Ma1ca02 (without source) (not expired)
pbcttt9200                                            B61Ma3ca02 (without source) (not expired)
pbcttt9201                                            B61Ma3ca02 (without source) (not expired)
fbccor0201m000d2                                      B61Ma ca02 (not expired)
fbccor0202m000d2                                      B61Ma ca02 (not expired)
fbccor0205m000d2                                      B61Ma ca02 (not expired)
fbccor0208m000d2                                      B61Ma1ca02 (not expired)
fbccor0213m000d2                                      B61Ma ca02 (not expired)
fbccor0215m000d2                                      B61Ma1ca02 (not expired)
fbccor0217m000d2                                      B61Ma ca02 (not expired)
fbccor0218m000d2                                      B61Ma ca02 (not expired)
fbccor0219m000d2                                      B61Ma1ca02 (not expired)
fbccor0221m000d2                                      B61Ma1ca02 (not expired)
fbccor0222m000d2                                      B61Ma1ca02 (not expired)
fbccor0224m000d2                                      B61Ma1ca02 (not expired)
fbccor0225m000d2                                      B61Ma3ca02 (not expired)
fbccor0226m000d2                                      B61Ma3ca02 (not expired)
fbccor0227m000d2                                      B61Ma3ca02 (not expired)
fbccor0228m000d2                                      B61Ma3ca02 (not expired)
fbccor0229m000d2                                      B61Ma3ca02 (not expired)
fbccor0230m000d2                                      B61Ma3ca02 (not expired)
fbccor0231m000d2                                      B61Ma3ca02 (not expired)
fbccor0232m000d2                                      B61Ma3ca02 (not expired)
fbccor0233m000d2                                      B61Ma3ca02 (not expired)
fbccor0234m000d2                                      B61Ma3ca02 (not expired)
fbccor0235m000d2                                      B61Ma3ca02 (not expired)
fbccor0236m000d2                                      B61Ma3ca02 (not expired)
fbccor0237m000d2                                      B61Ma3ca02 (not expired)
fbccor0238m000d2                                      B61Ma3ca02 (not expired)
fbccor0239m000d2                                      B61Ma3ca02 (not expired)
fbccor0240m000d2                                      B61Ma3ca02 (not expired)
fbccor0241m000d2                                      B61Ma3ca02 (not expired)
fbccor0242m000d2                                      B61Ma3ca02 (not expired)
fbccor0297m000d2                                      B61Ma3ca02 (not expired)
fbccor0298m000d2                                      B61Ma3ca02 (not expired)
fbcttc0201m000d2                                      B61Ma3ca02 (not expired)
fbcttd0401m000d2                                      B61Ma3ca02 (not expired)
fbcttf0105m000d2                                      B61Ma2ca02 (not expired)
fbcttf0201m000d2                                      B61Ma2ca02 (not expired)
fbcttf0220m000d2                                      B61Ma3ca02 (not expired)
fbcttf0238m000d2                                      B61Ma3ca02 (not expired)
fbcttf1206m000d2                                      B61Ma2ca02 (not expired)
fbcttf1206m100d2                                      B61Ma2ca02 (not expired)
fbcttf2250m000d2                                      B61Ma5ca02 (expired)
fbcttf4529m000d2                                      B61Ma3ca02 (not expired)
fbctti0202m000d2                                      B61Ma1ca02 (not expired)
fbctti0203m000d2                                      B61Ma1ca02 (not expired)
fbctti7200m000d2                                      B61Ma2ca02 (not expired)
fbcttt9200m000d2                                      B61Ma3ca02 (not expired)
rbccor0201010002                                      B61Ma ca02 (not expired)
rbccor0202010002                                      B61Ma ca02 (not expired)
rbccor0205110002                                      B61Ma ca02 (not expired)
rbccor0208110002                                      B61Ma1ca02 (not expired)
rbccor0213110002                                      B61Ma ca02 (not expired)
rbccor0215110002                                      B61Ma1ca02 (not expired)
rbccor0217110002                                      B61Ma ca02 (not expired)
rbccor0218110002                                      B61Ma ca02 (not expired)
rbccor0219110002                                      B61Ma1ca02 (not expired)
rbccor0221110002                                      B61Ma1ca02 (not expired)
rbccor0222110002                                      B61Ma1ca02 (not expired)
rbccor0224110002                                      B61Ma1ca02 (not expired)
rbccor0225110002                                      B61Ma3ca02 (not expired)
rbccor0226110002                                      B61Ma3ca02 (not expired)
rbccor0227110002                                      B61Ma3ca02 (not expired)
rbccor0228110002                                      B61Ma3ca02 (not expired)
rbccor0229110002                                      B61Ma3ca02 (not expired)
rbccor0230010002                                      B61Ma3ca02 (not expired)
rbccor0231010002                                      B61Ma3ca02 (not expired)
rbccor0232110002                                      B61Ma3ca02 (not expired)
rbccor0233110002                                      B61Ma3ca02 (not expired)
rbccor0235010002                                      B61Ma3ca02 (not expired)
rbccor0236010002                                      B61Ma3ca02 (not expired)
rbccor0237010002                                      B61Ma3ca02 (not expired)
rbccor0238010002                                      B61Ma3ca02 (not expired)
rbccor0239010002                                      B61Ma3ca02 (not expired)
rbccor0240010002                                      B61Ma3ca02 (not expired)
rbccor0241010002                                      B61Ma3ca02 (not expired)
rbccor0242110002                                      B61Ma3ca02 (not expired)
rbccor0299110002                                      B61Ma3ca02 (not expired)
rbccor9499010002                                      B61Ma3ca02 (not expired)
rbcsqlhenk01   2                                      B61Ma2ca02 (not expired)
rbcsqlhenk02   2                                      B61Ma2ca02 (not expired)
rbcsqliwan1    2                                      B61Ma5ca02 (not expired)
rbcsqloset     2                                      B61Ma3ca02 (not expired)
rbcttc0201010002                                      B61Ma2ca02 (not expired)
rbcttc0201020002                                      B61Ma3ca02 (not expired)
rbcttd0401010002                                      B61Ma3ca02 (not expired)
rbcttd0401020002                                      B61Ma3ca02 (not expired)
rbcttf4529     2                                      B61Ma3ca02 (not expired)
rbctti0201000012                                      B61Ma5ca02 (not expired)
rbctti0202010002                                      B61Ma1ca02 (not expired)
rbctti0202020002                                      B61Ma1ca02 (not expired)
rbctti0203010002                                      B61Ma1ca02 (not expired)
rbctti0203020002                                      B61Ma1ca02 (not expired)
rbctti0400120002                                      B61Ma2ca02 (not expired)
rbctti0400120012                                      B61Ma2ca02 (not expired)
cbccor0001                                            B61Ma ca02 (not expired)
cbccor0230100                                         B61Ma3ca02 (not expired)
cbcttc00017                                           B61Ma2ca02 (not expired)
cbcttd0401.01                                         B61Ma3ca02 (not expired)
cbcttd0401.02                                         B61Ma3ca02 (not expired)
cbcttd0401.03                                         B61Ma3ca02 (not expired)
cbcttf0238.01                                         B61Ma3ca02 (not expired)
cbcttf0238.02                                         B61Ma3ca02 (not expired)
cbcttf0238.03                                         B61Ma3ca02 (not expired)
cbcttf0238.04                                         B61Ma3ca02 (not expired)
cbcttf0238.05                                         B61Ma3ca02 (not expired)
cbcttf0238.06                                         B61Ma3ca02 (not expired)
cbcttf0238.07                                         B61Ma3ca02 (not expired)
cbcttf0238.08                                         B61Ma3ca02 (not expired)
cbcttf0238.09                                         B61Ma3ca02 (not expired)
cbcttfs0013                                           B61Ma5ca02 (not expired)
cbcttfs0014                                           B61Ma5ca02 (not expired)
cbctti00022                                           B61Ma2ca02 (not expired)
cbctti00028                                           B61Ma2ca02 (not expired)
cbctti00076                                           B61Ma2ca02 (not expired)
cbctti00077                                           B61Ma2ca02 (not expired)
cbctti00093                                           B61Ma2ca02 (not expired)
cbctti00099                                           B61Ma2ca02 (not expired)
cbctti00141                                           B61Ma2ca02 (not expired)
cbctti00143                                           B61Ma2ca02 (not expired)
cbctti00144                                           B61Ma2ca02 (not expired)
cbctti00396                                           B61Ma2ca02 (not expired)
cbctti00500                                           B61Ma2ca02 (not expired)
cbctti00501                                           B61Ma2ca02 (not expired)
cbctti00502                                           B61Ma2ca02 (not expired)
cbctti00582                                           B61Ma2ca02 (not expired)
cbctti0202.01                                         B61Ma1ca02 (not expired)
cbctti0203.01                                         B61Ma1ca02 (not expired)
cbctti20001                                           B61Ma2ca02 (not expired)
cbctti20004                                           B61Ma2ca02 (not expired)
cbctti20010                                           B61Ma2ca02 (not expired)
cbctti7000009                                         B61Ma2ca02 (not expired)
cbctti7000015                                         B61Ma2ca02 (not expired)
cbctti7000016                                         B61Ma2ca02 (not expired)
cbctti7000017                                         B61Ma2ca02 (not expired)
cbctti7000020                                         B61Ma2ca02 (not expired)
cbctti7000022                                         B61Ma2ca02 (not expired)
cbcttidll2                                            B61Ma2ca02 (not expired)
cbcttt0001                                            B61Ma3ca02 (not expired)
bbcbic___slm___                                       B61Ma6ca02 (with source) (not expired)
mbctcp0000200112                                      B61Ma3ca02 (expired)
mbcttc0000200112                                      B61Ma3ca02 (expired)
mbctwh0000200112                                      B61Ma3ca02 (expired)
obccor0001                                            B61Ma2ca02
obccor0200                                            B61Ma ca02
obccor0201                                            B61Ma ca02
obccor0202                                            B61Ma ca02
obccor0203                                            B61Ma2ca02
obccor0204                                            B61Ma ca02
obccor0205                                            B61Ma ca02
obccor0206                                            B61Ma1ca02
obccor0207                                            B61Ma ca02
obccor0208                                            B61Ma1ca02
obccor0210                                            B61Ma ca02
obccor0211                                            B61Ma ca02
obccor0212                                            B61Ma ca02
obccor0213                                            B61Ma ca02
obccor0215                                            B61Ma5ca02
obccor0216                                            B61Ma ca02
obccor0217                                            B61Ma ca02
obccor0218                                            B61Ma3ca02
obccor0219                                            B61Ma3ca02
obccor0220                                            B61Ma1ca02
obccor0221                                            B61Ma1ca02
obccor0222                                            B61Ma1ca02
obccor0223                                            B61Ma1ca02
obccor0224                                            B61Ma1ca02
obccor0225                                            B61Ma3ca02
obccor0226                                            B61Ma3ca02
obccor0227                                            B61Ma3ca02
obccor0228                                            B61Ma3ca02
obccor0229                                            B61Ma3ca02
obccor0230                                            B61Ma3ca02
obccor0231                                            B61Ma3ca02
obccor0232                                            B61Ma3ca02
obccor0233                                            B61Ma3ca02
obccor0235                                            B61Ma3ca02
obccor0236                                            B61Ma3ca02
obccor0237                                            B61Ma3ca02
obccor0238                                            B61Ma3ca02
obccor0239                                            B61Ma3ca02
obccor0240                                            B61Ma3ca02
obccor0241                                            B61Ma3ca02
obccor0242                                            B61Ma3ca02
obccor0297                                            B61Ma3ca02
obccor0299                                            B61Ma3ca02
obccor9000                                            B61Ma2ca02
obccortabledesc                                       B61Ma5ca02
obccortestgz                                          B61Ma ca02
obccorts220                                           B61Ma ca02
obcintdlltcfin                                        B61Ma5ca02
obcttc0100                                            B61Ma2ca02
obcttc0201                                            B61Ma3ca02
obcttcdll0001                                         B61Ma3ca02
obcttcdll0002                                         B61Ma2ca02
obcttd0401                                            B61Ma3ca02
obcttddll0001                                         B61Ma2ca02
obcttf0105                                            B61Ma2ca02
obcttf0110                                            B61Ma2ca02
obcttf0201                                            B61Ma5ca02
obcttf0220                                            B61Ma3ca02
obcttf0238                                            B61Ma3ca02
obcttf1206                                            B61Ma2ca02
obcttf1206m100                                        B61Ma4ca02
obcttf2250                                            B61Ma5ca02
obcttf4529                                            B61Ma3ca02
obcttfdll0001                                         B61Ma2ca02
obcttfdll0002                                         B61Ma2ca02
obcttfdll0003                                         B61Ma2ca02
obcttfdll0004                                         B61Ma ca02
obcttfdll0005                                         B61Ma1ca02
obcttfdll0006                                         B61Ma2ca02
obcttfdll0007                                         B61Ma3ca02
obcttfdll0008                                         B61Ma5ca02
obcttfdll0238                                         B61Ma3ca02
obctti0201                                            B61Ma2ca02
obctti0202                                            B61Ma3ca02
obctti0203                                            B61Ma2ca02
obctti7200                                            B61Ma2ca02
obcttidll0001                                         B61Ma5ca02
obcttidll00013                                        B61Ma2ca02
obcttidll0002                                         B61Ma2ca02
obcttidll0003                                         B61Ma5ca02
obcttidll0004                                         B61Ma1ca02
obcttt9200                                            B61Ma3ca02
obcttt9201                                            B61Ma3ca02
obctttdll0001                                         B61Ma1ca02
obccor0201010002                                      B61Ma ca02
obccor0202010002                                      B61Ma ca02
obccor0205110002                                      B61Ma ca02
obccor0208110002                                      B61Ma1ca02
obccor0213110002                                      B61Ma ca02
obccor0215110002                                      B61Ma1ca02
obccor0217110002                                      B61Ma ca02
obccor0218110002                                      B61Ma ca02
obccor0219110002                                      B61Ma1ca02
obccor0221110002                                      B61Ma1ca02
obccor0222110002                                      B61Ma1ca02
obccor0224110002                                      B61Ma1ca02
obccor0225110002                                      B61Ma3ca02
obccor0226110002                                      B61Ma3ca02
obccor0227110002                                      B61Ma3ca02
obccor0228110002                                      B61Ma3ca02
obccor0229110002                                      B61Ma3ca02
obccor0230010002                                      B61Ma3ca02
obccor0231010002                                      B61Ma3ca02
obccor0232110002                                      B61Ma3ca02
obccor0233110002                                      B61Ma3ca02
obccor0235010002                                      B61Ma3ca02
obccor0236010002                                      B61Ma3ca02
obccor0237010002                                      B61Ma3ca02
obccor0238010002                                      B61Ma3ca02
obccor0239010002                                      B61Ma3ca02
obccor0240010002                                      B61Ma3ca02
obccor0241010002                                      B61Ma3ca02
obccor0242110002                                      B61Ma3ca02
obccor0299110002                                      B61Ma3ca02
obccor9499010002                                      B61Ma3ca02
obcsqlhenk01   2                                      B61Ma2ca02
obcsqlhenk02   2                                      B61Ma2ca02
obcsqliwan1    2                                      B61Ma5ca02
obcsqloset     2                                      B61Ma3ca02
obcttc0201010002                                      B61Ma2ca02
obcttc0201020002                                      B61Ma3ca02
obcttd0401010002                                      B61Ma3ca02
obcttd0401020002                                      B61Ma3ca02
obcttf4529     2                                      B61Ma3ca02
obctti0201000012                                      B61Ma5ca02
obctti0202010002                                      B61Ma1ca02
obctti0202020002                                      B61Ma1ca02
obctti0203010002                                      B61Ma1ca02
obctti0203020002                                      B61Ma1ca02
obctti0400120002                                      B61Ma2ca02
obctti0400120012                                      B61Ma2ca02
lbcObjects          107                               B61Ma2ca02 (not expired)
lbcPost.type        112                               B61Ma3ca02 (not expired)
lbcbc.item.from     109                               B61Ma ca02 (not expired)
lbcbc0238.01        111                               B61Ma3ca02 (not expired)
lbcbccor0201.01     131                               B61Ma ca02 (not expired)
lbcbccors0205.01    116                               B61Ma ca02 (not expired)
lbcbccors0205.02    216                               B61Ma ca02 (not expired)
lbcbccors0205.03    216                               B61Ma ca02 (not expired)
lbcbccors0225.01    115                               B61Ma3ca02 (not expired)
lbcbccors0225.02    113                               B61Ma3ca02 (not expired)
lbcbccors0225.03    112                               B61Ma3ca02 (not expired)
lbcbccors0225.04    112                               B61Ma3ca02 (not expired)
lbcbccors0225.05    118                               B61Ma3ca02 (not expired)
lbcbccors0225.06    116                               B61Ma3ca02 (not expired)
lbcbccors0225.07    110                               B61Ma3ca02 (not expired)
lbcbccors0225.08    113                               B61Ma3ca02 (not expired)
lbcbcgen.blocked    107                               B61Ma1ca02 (not expired)
lbcbcgen.blocked.ep 114                               B61Ma1ca02 (not expired)
lbcbcgen.bom        103                               B61Ma2ca02 (not expired)
lbcbcgen.committed  109                               B61Ma1ca02 (not expired)
lbcbcgen.committed.p120                               B61Ma1ca02 (not expired)
lbcbcgen.loc.alloc  118                               B61Ma1ca02 (not expired)
lbcbcgen.onhand     107                               B61Ma1ca02 (not expired)
lbcbcttc0201.16     127                               B61Ma2ca02 (not expired)
lbcbcttc0201.17     141                               B61Ma2ca02 (not expired)
lbcbcttc0201.18     107                               B61Ma2ca02 (not expired)
lbcbcttc0201.19     117                               B61Ma3ca02 (not expired)
lbcbcttd.pur.pric.gr120                               B61Ma3ca02 (not expired)
lbcbcttd.pur.pric.gr211                               B61Ma3ca02 (not expired)
lbcbcttd.sls.pric.gr117                               B61Ma3ca02 (not expired)
lbcbcttd.sls.pric.gr211                               B61Ma3ca02 (not expired)
lbcbcttd0001.sort   115                               B61Ma2ca02 (not expired)
lbcbcttd0002        128                               B61Ma2ca02 (not expired)
lbcbcttd0401.01     122                               B61Ma3ca02 (not expired)
lbcbcttd0401.01     308                               B61Ma3ca02 (not expired)
lbcbcttd0401.02     204                               B61Ma3ca02 (not expired)
lbcbcttd0401.03     120                               B61Ma3ca02 (not expired)
lbcbcttf001.cvat.f  108                               B61Ma1ca02 (not expired)
lbcbcttf001.fcmp    117                               B61Ma3ca02 (not expired)
lbcbcttf020.line    118                               B61Ma ca02 (not expired)
lbcbcttf021.amnt    106                               B61Ma3ca02 (not expired)
lbcbctti001.cdrw    107                               B61Ma2ca02 (not expired)
lbcbctti001.cmba    114                               B61Ma2ca02 (not expired)
lbcbctti001.eitm    116                               B61Ma2ca02 (not expired)
lbcbctti001.revi    108                               B61Ma2ca02 (not expired)
lbcbctti0202.01     148                               B61Ma1ca02 (not expired)
lbcbctti700.mgdr    116                               B61Ma2ca02 (not expired)
lbcbcttt9200.01     138                               B61Ma3ca02 (not expired)
lbcbcttt9200.02     115                               B61Ma3ca02 (not expired)
lbcbctttd0401.sel.on112                               B61Ma3ca02 (not expired)
lbccomm             111                               B61Ma3ca02 (not expired)
lbccor020101000001  140                               B61Ma ca02 (not expired)
lbccor020101000002  140                               B61Ma ca02 (not expired)
lbccor0201m000001   140                               B61Ma ca02 (not expired)
lbccor0202001       130                               B61Ma ca02 (not expired)
lbccor020201000001  130                               B61Ma ca02 (not expired)
lbccor020201000002  130                               B61Ma ca02 (not expired)
lbccor020201000003  130                               B61Ma ca02 (not expired)
lbccor020201000004  132                               B61Ma ca02 (not expired)
lbccor020201000005  132                               B61Ma ca02 (not expired)
lbccor020201000006  130                               B61Ma ca02 (not expired)
lbccor020201000007  151                               B61Ma ca02 (not expired)
lbccor0202m000001   130                               B61Ma ca02 (not expired)
lbccor020511000001  146                               B61Ma ca02 (not expired)
lbccor0205m000001   146                               B61Ma ca02 (not expired)
lbccor020811000001  156                               B61Ma1ca02 (not expired)
lbccor0208m000001   156                               B61Ma1ca02 (not expired)
lbccor021311000001  143                               B61Ma ca02 (not expired)
lbccor0213m000001   162                               B61Ma ca02 (not expired)
lbccor0213m000002   143                               B61Ma ca02 (not expired)
lbccor021511000001  156                               B61Ma1ca02 (not expired)
lbccor0215m000001   133                               B61Ma1ca02 (not expired)
lbccor0215m000002   156                               B61Ma1ca02 (not expired)
lbccor021711000001  152                               B61Ma ca02 (not expired)
lbccor0217m000001   152                               B61Ma ca02 (not expired)
lbccor021811000001  153                               B61Ma ca02 (not expired)
lbccor0218m000001   160                               B61Ma ca02 (not expired)
lbccor021911000001  126                               B61Ma1ca02 (not expired)
lbccor0219m000001   142                               B61Ma1ca02 (not expired)
lbccor0219m000002   136                               B61Ma ca02 (not expired)
lbccor022111000001  156                               B61Ma1ca02 (not expired)
lbccor0221m000001   139                               B61Ma1ca02 (not expired)
lbccor022211000001  159                               B61Ma1ca02 (not expired)
lbccor0222m000001   132                               B61Ma1ca02 (not expired)
lbccor022411000001  154                               B61Ma1ca02 (not expired)
lbccor0224m000001   154                               B61Ma1ca02 (not expired)
lbccor022511000001  136                               B61Ma3ca02 (not expired)
lbccor0225m000001   136                               B61Ma3ca02 (not expired)
lbccor022611000001  142                               B61Ma3ca02 (not expired)
lbccor022611000002  142                               B61Ma3ca02 (not expired)
lbccor0226m000001   142                               B61Ma3ca02 (not expired)
lbccor022711000001  150                               B61Ma3ca02 (not expired)
lbccor022711000002  150                               B61Ma2ca02 (not expired)
lbccor0227m000001   150                               B61Ma3ca02 (not expired)
lbccor0227m000002   150                               B61Ma2ca02 (not expired)
lbccor022811000001  160                               B61Ma3ca02 (not expired)
lbccor0228m000001   160                               B61Ma3ca02 (not expired)
lbccor022911000001  150                               B61Ma3ca02 (not expired)
lbccor0229m000001   150                               B61Ma3ca02 (not expired)
lbccor0229m000002   150                               B61Ma3ca02 (not expired)
lbccor0229m000003   130                               B61Ma3ca02 (not expired)
lbccor023001000001  133                               B61Ma3ca02 (not expired)
lbccor0230m000001   150                               B61Ma3ca02 (not expired)
lbccor023101000001  131                               B61Ma3ca02 (not expired)
lbccor023101000002  131                               B61Ma3ca02 (not expired)
lbccor0231m000001   130                               B61Ma3ca02 (not expired)
lbccor0231m000002   147                               B61Ma3ca02 (not expired)
lbccor023211000001  141                               B61Ma3ca02 (not expired)
lbccor0232m000001   141                               B61Ma3ca02 (not expired)
lbccor023311000001  160                               B61Ma3ca02 (not expired)
lbccor0233m000001   160                               B61Ma3ca02 (not expired)
lbccor0234m000001   164                               B61Ma3ca02 (not expired)
lbccor023501000001  135                               B61Ma3ca02 (not expired)
lbccor0235m000001   125                               B61Ma3ca02 (not expired)
lbccor0235m000002   125                               B61Ma3ca02 (not expired)
lbccor0235m000004   135                               B61Ma3ca02 (not expired)
lbccor023601000001  124                               B61Ma3ca02 (not expired)
lbccor0236m000001   133                               B61Ma3ca02 (not expired)
lbccor023701000001  149                               B61Ma3ca02 (not expired)
lbccor0237m000001   125                               B61Ma3ca02 (not expired)
lbccor0237m000002   149                               B61Ma3ca02 (not expired)
lbccor023801000001  121                               B61Ma3ca02 (not expired)
lbccor0238m000001   121                               B61Ma3ca02 (not expired)
lbccor0238m000002   121                               B61Ma3ca02 (not expired)
lbccor023901000001  129                               B61Ma3ca02 (not expired)
lbccor0239m000001   129                               B61Ma3ca02 (not expired)
lbccor0239m000002   129                               B61Ma3ca02 (not expired)
lbccor0239m000003   126                               B61Ma3ca02 (not expired)
lbccor024001000001  138                               B61Ma3ca02 (not expired)
lbccor024001000002  112                               B61Ma3ca02 (not expired)
lbccor024001000003  114                               B61Ma3ca02 (not expired)
lbccor024011000001  108                               B61Ma3ca02 (not expired)
lbccor024011000002  108                               B61Ma3ca02 (not expired)
lbccor0240m000001   108                               B61Ma3ca02 (not expired)
lbccor024101000001  112                               B61Ma3ca02 (not expired)
lbccor024101000002  146                               B61Ma3ca02 (not expired)
lbccor0241m000001   149                               B61Ma3ca02 (not expired)
lbccor024211000001  153                               B61Ma3ca02 (not expired)
lbccor0242m000001   153                               B61Ma3ca02 (not expired)
lbccor0297m000001   139                               B61Ma3ca02 (not expired)
lbccor0298m000001   139                               B61Ma3ca02 (not expired)
lbccor029911000001  113                               B61Ma3ca02 (not expired)
lbccor0299m000001   130                               B61Ma3ca02 (not expired)
lbccor949901000001  105                               B61Ma3ca02 (not expired)
lbccoriwan001       104                               B61Ma3ca02 (not expired)
lbccoriwan2001      104                               B61Ma3ca02 (not expired)
lbccosts            105                               B61Ma3ca02 (not expired)
lbcdmcom.browse     106                               B61Ma2ca02 (not expired)
lbcdmdoc700.alit    111                               B61Ma2ca02 (not expired)
lbcebom             115                               B61Ma2ca02 (not expired)
lbcgitem            112                               B61Ma2ca02 (not expired)
lbcitem             104                               B61Ma3ca02 (not expired)
lbcitem.to          107                               B61Ma ca02 (not expired)
lbcloca             108                               B61Ma ca02 (not expired)
lbclot              103                               B61Ma ca02 (not expired)
lbcmauc             104                               B61Ma3ca02 (not expired)
lbcppc.inv          107                               B61Ma3ca02 (not expired)
lbcppc.pv           114                               B61Ma3ca02 (not expired)
lbcprin             118                               B61Ma2ca02 (not expired)
lbcpurchase         108                               B61Ma2ca02 (not expired)
lbcsales            105                               B61Ma2ca02 (not expired)
lbcsbom             114                               B61Ma2ca02 (not expired)
lbcsimulate         108                               B61Ma ca02 (not expired)
lbcsls.contract     114                               B61Ma2ca02 (not expired)
lbcstorage.data     112                               B61Ma ca02 (not expired)
lbctccom100.bprl    121                               B61Ma3ca02 (not expired)
lbctcgen.seqno      108                               B61Ma3ca02 (not expired)
lbctcibd001.item    104                               B61Ma2ca02 (not expired)
lbctcibd007.item    104                               B61Ma5ca02 (not expired)
lbcticpr110.chpr    101                               B61Ma5ca02 (not expired)
lbcticpr110.cpch    114                               B61Ma5ca02 (not expired)
lbcticpr220.base    114                               B61Ma5ca02 (not expired)
lbctiipd001.item    104                               B61Ma2ca02 (not expired)
lbctpgen.guid       109                               B61Ma3ca02 (not expired)
lbctrans.date       211                               B61Ma ca02 (not expired)
lbctt700i.atyp      109                               B61Ma2ca02 (not expired)
lbcttc0201m000001   145                               B61Ma2ca02 (not expired)
lbcttd.0401.1001    104                               B61Ma3ca02 (not expired)
lbcttd.0401.1002    110                               B61Ma3ca02 (not expired)
lbcttd.0401.1003    120                               B61Ma3ca02 (not expired)
lbcttd.0401.1004    117                               B61Ma3ca02 (not expired)
lbcttd.0401.1005    114                               B61Ma3ca02 (not expired)
lbcttd.0401001      132                               B61Ma3ca02 (not expired)
lbcttd.0401002      105                               B61Ma3ca02 (not expired)
lbcttd0000001 1001  116                               B61Ma1ca02 (not expired)
lbcttd000010011001  116                               B61Ma1ca02 (not expired)
lbcttd000010021001  116                               B61Ma3ca02 (not expired)
lbcttd040101000001  160                               B61Ma3ca02 (not expired)
lbcttd040102000001  107                               B61Ma3ca02 (not expired)
lbcttd040102000002  160                               B61Ma3ca02 (not expired)
lbcttd040103000001  107                               B61Ma3ca02 (not expired)
lbcttd040104000001  107                               B61Ma3ca02 (not expired)
lbcttd040105000001  107                               B61Ma3ca02 (not expired)
lbcttd040106000001  107                               B61Ma3ca02 (not expired)
lbcttd040107000001  107                               B61Ma3ca02 (not expired)
lbcttd040108000001  107                               B61Ma3ca02 (not expired)
lbcttd040109000001  107                               B61Ma3ca02 (not expired)
lbcttd04010a000001  107                               B61Ma3ca02 (not expired)
lbcttd04010b000001  107                               B61Ma3ca02 (not expired)
lbcttd04010c000001  107                               B61Ma3ca02 (not expired)
lbcttd04010d000001  107                               B61Ma3ca02 (not expired)
lbcttd04010e000001  107                               B61Ma3ca02 (not expired)
lbcttd04010f000001  107                               B61Ma3ca02 (not expired)
lbcttd040111000001  152                               B61Ma3ca02 (not expired)
lbcttd0401m000001   160                               B61Ma3ca02 (not expired)
lbcttd0401m000002   155                               B61Ma3ca02 (not expired)
lbcttf.aext         115                               B61Ma ca02 (not expired)
lbcttf.anbr         112                               B61Ma ca02 (not expired)
lbcttf.book         110                               B61Ma ca02 (not expired)
lbcttf.meth         119                               B61Ma ca02 (not expired)
lbcttf.ndky         108                               B61Ma3ca02 (not expired)
lbcttf.odky         108                               B61Ma3ca02 (not expired)
lbcttf.stat001      104                               B61Ma2ca02 (not expired)
lbcttf.stat002      110                               B61Ma2ca02 (not expired)
lbcttf.stat003      105                               B61Ma2ca02 (not expired)
lbcttf.tkey         115                               B61Ma3ca02 (not expired)
lbcttf000010021001  107                               B61Ma3ca02 (not expired)
lbcttf000030011001  123                               B61Ma5ca02 (not expired)
lbcttf000030011002  123                               B61Ma3ca02 (not expired)
lbcttf0238.01       110                               B61Ma3ca02 (not expired)
lbcttf0238.02       116                               B61Ma3ca02 (not expired)
lbcttf0238m000001   133                               B61Ma3ca02 (not expired)
lbcttf106.01        126                               B61Ma2ca02 (not expired)
lbcttf106.03        107                               B61Ma2ca02 (not expired)
lbcttf106002        144                               B61Ma2ca02 (not expired)
lbcttf10601001      116                               B61Ma2ca02 (not expired)
lbcttf10602001      124                               B61Ma2ca02 (not expired)
lbcttf1206.01       110                               B61Ma ca02 (not expired)
lbcttf1206m000001   153                               B61Ma2ca02 (not expired)
lbcttf1206m100001   148                               B61Ma2ca02 (not expired)
lbcttf1206m100002   148                               B61Ma2ca02 (not expired)
lbcttf2250001       127                               B61Ma3ca02 (not expired)
lbcttf2250002       137                               B61Ma4ca02 (not expired)
lbcttf2250m000001   137                               B61Ma4ca02 (not expired)
lbcttf2250m000002   127                               B61Ma5ca02 (not expired)
lbcttf4529001       140                               B61Ma3ca02 (not expired)
lbcttf4529m000002   140                               B61Ma3ca02 (not expired)
lbcttgen.h.comp     107                               B61Ma3ca02 (not expired)
lbcttgen.h.date     104                               B61Ma3ca02 (not expired)
lbcttgen.page       104                               B61Ma3ca02 (not expired)
lbctti0000100112001 134                               B61Ma2ca02 (not expired)
lbctti000010021001  122                               B61Ma2ca02 (not expired)
lbctti001001        138                               B61Ma1ca02 (not expired)
lbctti001002        138                               B61Ma2ca02 (not expired)
lbctti00101001      126                               B61Ma2ca02 (not expired)
lbctti020201000001  157                               B61Ma1ca02 (not expired)
lbctti020202000001  160                               B61Ma1ca02 (not expired)
lbctti0202m000001   142                               B61Ma1ca02 (not expired)
lbctti020301000001  156                               B61Ma1ca02 (not expired)
lbctti020302000001  160                               B61Ma1ca02 (not expired)
lbctti0203m000001   123                               B61Ma1ca02 (not expired)
lbctti040012000001  146                               B61Ma2ca02 (not expired)
lbctti040012001001  146                               B61Ma2ca02 (not expired)
lbctti700.afil      109                               B61Ma2ca02 (not expired)
lbctti700.drenv     117                               B61Ma2ca02 (not expired)
lbctti700.dtyp      113                               B61Ma2ca02 (not expired)
lbctti700.efdt      114                               B61Ma2ca02 (not expired)
lbctti700.file      104                               B61Ma2ca02 (not expired)
lbctti700.fnam      120                               B61Ma2ca02 (not expired)
lbctti700.fpth      109                               B61Ma2ca02 (not expired)
lbctti700.hname     109                               B61Ma2ca02 (not expired)
lbctti700.hsid      104                               B61Ma2ca02 (not expired)
lbctti700.lhst      110                               B61Ma2ca02 (not expired)
lbctti700.libr      107                               B61Ma2ca02 (not expired)
lbctti700.ltyp      126                               B61Ma2ca02 (not expired)
lbctti700.warea     109                               B61Ma2ca02 (not expired)
lbctti7100.alit     111                               B61Ma2ca02 (not expired)
lbctti7100.browse   106                               B61Ma2ca02 (not expired)
lbctti7100m000001   130                               B61Ma2ca02 (not expired)
lbctti7100m100001   135                               B61Ma2ca02 (not expired)
lbctti7200m000001   129                               B61Ma2ca02 (not expired)
lbcwh.receipt       130                               B61Ma ca02 (not expired)
lbcwhgen.line       104                               B61Ma3ca02 (not expired)
lbcwhinh005.prty    114                               B61Ma3ca02 (not expired)
lbcwhinh006.appl    110                               B61Ma3ca02 (not expired)
lbcwhinh006.auto    109                               B61Ma3ca02 (not expired)
lbcwhinh006.odvc    113                               B61Ma3ca02 (not expired)
lbcwhinh200.oorg    112                               B61Ma3ca02 (not expired)
lbcwhinh200.orno    105                               B61Ma3ca02 (not expired)
lbcwhinh200.oset    103                               B61Ma3ca02 (not expired)
lbcwhinh210.qadv    107                               B61Ma3ca02 (not expired)
lbcwhinh210.qapr    108                               B61Ma3ca02 (not expired)
lbcwhinh210.qput    108                               B61Ma3ca02 (not expired)
lbcwhinh215.acti    108                               B61Ma3ca02 (not expired)
lbcwhinh220.qshp    116                               B61Ma ca02 (not expired)
Fbccor0201m000d2                                      B61Ma ca02
Fbccor0202m000d2                                      B61Ma ca02
Fbccor0205m000d2                                      B61Ma ca02
Fbccor0208m000d2                                      B61Ma1ca02
Fbccor0213m000d2                                      B61Ma ca02
Fbccor0215m000d2                                      B61Ma1ca02
Fbccor0217m000d2                                      B61Ma ca02
Fbccor0218m000d2                                      B61Ma ca02
Fbccor0219m000d2                                      B61Ma1ca02
Fbccor0221m000d2                                      B61Ma1ca02
Fbccor0222m000d2                                      B61Ma3ca02
Fbccor0224m000d2                                      B61Ma1ca02
Fbccor0225m000d2                                      B61Ma3ca02
Fbccor0226m000d2                                      B61Ma3ca02
Fbccor0227m000d2                                      B61Ma3ca02
Fbccor0228m000d2                                      B61Ma3ca02
Fbccor0229m000d2                                      B61Ma3ca02
Fbccor0230m000d2                                      B61Ma3ca02
Fbccor0231m000d2                                      B61Ma3ca02
Fbccor0232m000d2                                      B61Ma3ca02
Fbccor0233m000d2                                      B61Ma3ca02
Fbccor0234m000d2                                      B61Ma3ca02
Fbccor0235m000d2                                      B61Ma3ca02
Fbccor0236m000d2                                      B61Ma3ca02
Fbccor0237m000d2                                      B61Ma3ca02
Fbccor0238m000d2                                      B61Ma3ca02
Fbccor0239m000d2                                      B61Ma3ca02
Fbccor0240m000d2                                      B61Ma3ca02
Fbccor0241m000d2                                      B61Ma3ca02
Fbccor0242m000d2                                      B61Ma3ca02
Fbccor0297m000d2                                      B61Ma3ca02
Fbccor0298m000d2                                      B61Ma3ca02
Fbcttc0201m000d2                                      B61Ma3ca02
Fbcttd0401m000d2                                      B61Ma3ca02
Fbcttf0105m000d2                                      B61Ma2ca02
Fbcttf0201m000d2                                      B61Ma2ca02
Fbcttf0220m000d2                                      B61Ma3ca02
Fbcttf0238m000d2                                      B61Ma3ca02
Fbcttf1206m000d2                                      B61Ma2ca02
Fbcttf1206m100d2                                      B61Ma2ca02
Fbcttf4529m000d2                                      B61Ma3ca02
Fbctti0202m000d2                                      B61Ma1ca02
Fbctti0203m000d2                                      B61Ma1ca02
Fbctti7200m000d2                                      B61Ma2ca02
Fbcttt9200m000d2                                      B61Ma3ca02
Mbctcp0000100112                                      B61Ma3ca02
Mbcttc0000000012                                      B61Ma3ca02
Mbcttc0000000212                                      B61Ma3ca02
Mbcttc0000100112                                      B61Ma3ca02
Mbcttd0000100112                                      B61Ma1ca02
Mbcttd0000100212                                      B61Ma3ca02
Mbcttf0000100112                                      B61Ma3ca02
Mbcttf0000100212                                      B61Ma6ca02
Mbcttf0000200112                                      B61Ma2ca02
Mbcttf0000300112                                      B61Ma3ca02
Mbctti0000100112                                      B61Ma2ca02
Mbctti0000100212                                      B61Ma2ca02
Mbctwh0000100112                                      B61Ma3ca02
